@@ -20,12 +20,11 @@
 { "Scroll_Lock", 0xFF14 },
 { "Sys_Req", 0xFF15 },
 { "Escape", 0xFF1B },
-{ "Delete", 0xFFFF },
 { "Multi_key", 0xFF20 },
 { "Kanji", 0xFF21 },
 { "Muhenkan", 0xFF22 },
-{ "Henkan_Mode", 0xFF23 },
 { "Henkan", 0xFF23 },
+{ "Henkan_Mode", 0xFF23 },
 { "Romaji", 0xFF24 },
 { "Hiragana", 0xFF25 },
 { "Katakana", 0xFF26 },
@@ -39,20 +38,36 @@
 { "Kana_Shift", 0xFF2E },
 { "Eisu_Shift", 0xFF2F },
 { "Eisu_toggle", 0xFF30 },
+{ "Hangul", 0xFF31 },
+{ "Hangul_Start", 0xFF32 },
+{ "Hangul_End", 0xFF33 },
+{ "Hangul_Hanja", 0xFF34 },
+{ "Hangul_Jamo", 0xFF35 },
+{ "Hangul_Romaja", 0xFF36 },
+{ "Codeinput", 0xFF37 },
+{ "Hangul_Jeonja", 0xFF38 },
+{ "Hangul_Banja", 0xFF39 },
+{ "Hangul_PreHanja", 0xFF3A },
+{ "Hangul_PostHanja", 0xFF3B },
+{ "SingleCandidate", 0xFF3C },
+{ "MultipleCandidate", 0xFF3D },
+{ "PreviousCandidate", 0xFF3E },
+{ "Hangul_Special", 0xFF3F },
 { "Home", 0xFF50 },
 { "Left", 0xFF51 },
 { "Up", 0xFF52 },
 { "Right", 0xFF53 },
 { "Down", 0xFF54 },
 { "Prior", 0xFF55 },
+#ifndef TK_NO_DEPRECATED
 { "Page_Up", 0xFF55 },
+#endif
 { "Next", 0xFF56 },
+#ifndef TK_NO_DEPRECATED
 { "Page_Down", 0xFF56 },
+#endif
 { "End", 0xFF57 },
 { "Begin", 0xFF58 },
-{ "Win_L", 0xFF5B },
-{ "Win_R", 0xFF5C },
-{ "App", 0xFF5D },
 { "Select", 0xFF60 },
 { "Print", 0xFF61 },
 { "Execute", 0xFF62 },
@@ -60,12 +75,19 @@
 { "Undo", 0xFF65 },
 { "Redo", 0xFF66 },
 { "Menu", 0xFF67 },
+#ifndef TK_NO_DEPRECATED
+{ "App", 0xFF67 },
+#endif
 { "Find", 0xFF68 },
 { "Cancel", 0xFF69 },
 { "Help", 0xFF6A },
 { "Break", 0xFF6B },
 { "Mode_switch", 0xFF7E },
 { "script_switch", 0xFF7E },
+{ "kana_switch", 0xFF7E },
+{ "Arabic_switch", 0xFF7E },
+{ "Greek_switch", 0xFF7E },
+{ "Hebrew_switch", 0xFF7E },
 { "Num_Lock", 0xFF7F },
 { "KP_Space", 0xFF80 },
 { "KP_Tab", 0xFF89 },
@@ -87,7 +109,6 @@
 { "KP_Begin", 0xFF9D },
 { "KP_Insert", 0xFF9E },
 { "KP_Delete", 0xFF9F },
-{ "KP_Equal", 0xFFBD },
 { "KP_Multiply", 0xFFAA },
 { "KP_Add", 0xFFAB },
 { "KP_Separator", 0xFFAC },
@@ -104,6 +125,7 @@
 { "KP_7", 0xFFB7 },
 { "KP_8", 0xFFB8 },
 { "KP_9", 0xFFB9 },
+{ "KP_Equal", 0xFFBD },
 { "F1", 0xFFBE },
 { "F2", 0xFFBF },
 { "F3", 0xFFC0 },
@@ -115,55 +137,105 @@
 { "F9", 0xFFC6 },
 { "F10", 0xFFC7 },
 { "F11", 0xFFC8 },
+#ifndef TK_NO_DEPRECATED
 { "L1", 0xFFC8 },
+#endif
 { "F12", 0xFFC9 },
+#ifndef TK_NO_DEPRECATED
 { "L2", 0xFFC9 },
+#endif
 { "F13", 0xFFCA },
+#ifndef TK_NO_DEPRECATED
 { "L3", 0xFFCA },
+#endif
 { "F14", 0xFFCB },
+#ifndef TK_NO_DEPRECATED
 { "L4", 0xFFCB },
+#endif
 { "F15", 0xFFCC },
+#ifndef TK_NO_DEPRECATED
 { "L5", 0xFFCC },
+#endif
 { "F16", 0xFFCD },
+#ifndef TK_NO_DEPRECATED
 { "L6", 0xFFCD },
+#endif
 { "F17", 0xFFCE },
+#ifndef TK_NO_DEPRECATED
 { "L7", 0xFFCE },
+#endif
 { "F18", 0xFFCF },
+#ifndef TK_NO_DEPRECATED
 { "L8", 0xFFCF },
+#endif
 { "F19", 0xFFD0 },
+#ifndef TK_NO_DEPRECATED
 { "L9", 0xFFD0 },
+#endif
 { "F20", 0xFFD1 },
+#ifndef TK_NO_DEPRECATED
 { "L10", 0xFFD1 },
+#endif
 { "F21", 0xFFD2 },
+#ifndef TK_NO_DEPRECATED
 { "R1", 0xFFD2 },
+#endif
 { "F22", 0xFFD3 },
+#ifndef TK_NO_DEPRECATED
 { "R2", 0xFFD3 },
+#endif
 { "F23", 0xFFD4 },
+#ifndef TK_NO_DEPRECATED
 { "R3", 0xFFD4 },
+#endif
 { "F24", 0xFFD5 },
+#ifndef TK_NO_DEPRECATED
 { "R4", 0xFFD5 },
+#endif
 { "F25", 0xFFD6 },
+#ifndef TK_NO_DEPRECATED
 { "R5", 0xFFD6 },
+#endif
 { "F26", 0xFFD7 },
+#ifndef TK_NO_DEPRECATED
 { "R6", 0xFFD7 },
+#endif
 { "F27", 0xFFD8 },
+#ifndef TK_NO_DEPRECATED
 { "R7", 0xFFD8 },
+#endif
 { "F28", 0xFFD9 },
+#ifndef TK_NO_DEPRECATED
 { "R8", 0xFFD9 },
+#endif
 { "F29", 0xFFDA },
+#ifndef TK_NO_DEPRECATED
 { "R9", 0xFFDA },
+#endif
 { "F30", 0xFFDB },
+#ifndef TK_NO_DEPRECATED
 { "R10", 0xFFDB },
+#endif
 { "F31", 0xFFDC },
+#ifndef TK_NO_DEPRECATED
 { "R11", 0xFFDC },
+#endif
 { "F32", 0xFFDD },
+#ifndef TK_NO_DEPRECATED
 { "R12", 0xFFDD },
+#endif
 { "F33", 0xFFDE },
+#ifndef TK_NO_DEPRECATED
 { "R13", 0xFFDE },
+#endif
 { "F34", 0xFFDF },
+#ifndef TK_NO_DEPRECATED
 { "R14", 0xFFDF },
+#endif
 { "F35", 0xFFE0 },
+#ifndef TK_NO_DEPRECATED
 { "R15", 0xFFE0 },
+#endif
 { "Shift_L", 0xFFE1 },
 { "Shift_R", 0xFFE2 },
 { "Control_L", 0xFFE3 },
@@ -175,14 +247,185 @@
 { "Alt_L", 0xFFE9 },
 { "Alt_R", 0xFFEA },
 { "Super_L", 0xFFEB },
+#ifndef TK_NO_DEPRECATED
+{ "Win_L", 0xFFEB },
+#endif
 { "Super_R", 0xFFEC },
+#ifndef TK_NO_DEPRECATED
+{ "Win_R", 0xFFEC },
+#endif
 { "Hyper_L", 0xFFED },
 { "Hyper_R", 0xFFEE },
+{ "braille_dot_1", 0xFFF1 },
+{ "braille_dot_2", 0xFFF2 },
+{ "braille_dot_3", 0xFFF3 },
+{ "braille_dot_4", 0xFFF4 },
+{ "braille_dot_5", 0xFFF5 },
+{ "braille_dot_6", 0xFFF6 },
+{ "braille_dot_7", 0xFFF7 },
+{ "braille_dot_8", 0xFFF8 },
+{ "braille_dot_9", 0xFFF9 },
+{ "braille_dot_10", 0xFFFA },
+{ "Delete", 0xFFFF },
+{ "ISO_Lock", 0xFE01 },
+{ "ISO_Level2_Latch", 0xFE02 },
+{ "ISO_Level3_Shift", 0xFE03 },
+{ "ISO_Level3_Latch", 0xFE04 },
+{ "ISO_Level3_Lock", 0xFE05 },
+{ "ISO_Group_Shift", 0xFF7E },
+{ "ISO_Group_Latch", 0xFE06 },
+{ "ISO_Group_Lock", 0xFE07 },
+{ "ISO_Next_Group", 0xFE08 },
+{ "ISO_Next_Group_Lock", 0xFE09 },
+{ "ISO_Prev_Group", 0xFE0A },
+{ "ISO_Prev_Group_Lock", 0xFE0B },
+{ "ISO_First_Group", 0xFE0C },
+{ "ISO_First_Group_Lock", 0xFE0D },
+{ "ISO_Last_Group", 0xFE0E },
+{ "ISO_Last_Group_Lock", 0xFE0F },
+{ "ISO_Level5_Shift", 0xFE11 },
+{ "ISO_Level5_Latch", 0xFE12 },
+{ "ISO_Level5_Lock", 0xFE13 },
+{ "ISO_Left_Tab", 0xFE20 },
+{ "ISO_Move_Line_Up", 0xFE21 },
+{ "ISO_Move_Line_Down", 0xFE22 },
+{ "ISO_Partial_Line_Up", 0xFE23 },
+{ "ISO_Partial_Line_Down", 0xFE24 },
+{ "ISO_Partial_Space_Left", 0xFE25 },
+{ "ISO_Partial_Space_Right", 0xFE26 },
+{ "ISO_Set_Margin_Left", 0xFE27 },
+{ "ISO_Set_Margin_Right", 0xFE28 },
+{ "ISO_Release_Margin_Left", 0xFE29 },
+{ "ISO_Release_Margin_Right", 0xFE2A },
+{ "ISO_Release_Both_Margins", 0xFE2B },
+{ "ISO_Fast_Cursor_Left", 0xFE2C },
+{ "ISO_Fast_Cursor_Right", 0xFE2D },
+{ "ISO_Fast_Cursor_Up", 0xFE2E },
+{ "ISO_Fast_Cursor_Down", 0xFE2F },
+{ "ISO_Continuous_Underline", 0xFE30 },
+{ "ISO_Discontinuous_Underline", 0xFE31 },
+{ "ISO_Emphasize", 0xFE32 },
+{ "ISO_Center_Object", 0xFE33 },
+{ "ISO_Enter", 0xFE34 },
+{ "dead_grave", 0xFE50 },
+{ "dead_acute", 0xFE51 },
+{ "dead_circumflex", 0xFE52 },
+{ "dead_tilde", 0xFE53 },
+{ "dead_perispomeni", 0xFE53 },
+{ "dead_macron", 0xFE54 },
+{ "dead_breve", 0xFE55 },
+{ "dead_abovedot", 0xFE56 },
+{ "dead_diaeresis", 0xFE57 },
+{ "dead_abovering", 0xFE58 },
+{ "dead_doubleacute", 0xFE59 },
+{ "dead_caron", 0xFE5A },
+{ "dead_cedilla", 0xFE5B },
+{ "dead_ogonek", 0xFE5C },
+{ "dead_iota", 0xFE5D },
+{ "dead_voiced_sound", 0xFE5E },
+{ "dead_semivoiced_sound", 0xFE5F },
+{ "dead_belowdot", 0xFE60 },
+{ "dead_hook", 0xFE61 },
+{ "dead_horn", 0xFE62 },
+{ "dead_stroke", 0xFE63 },
+{ "dead_abovecomma", 0xFE64 },
+{ "dead_psili", 0xFE64 },
+{ "dead_abovereversedcomma", 0xFE65 },
+{ "dead_dasia", 0xFE65 },
+{ "dead_doublegrave", 0xFE66 },
+{ "dead_belowring", 0xFE67 },
+{ "dead_belowmacron", 0xFE68 },
+{ "dead_belowcircumflex", 0xFE69 },
+{ "dead_belowtilde", 0xFE6A },
+{ "dead_belowbreve", 0xFE6B },
+{ "dead_belowdiaeresis", 0xFE6C },
+{ "dead_invertedbreve", 0xFE6D },
+{ "dead_belowcomma", 0xFE6E },
+{ "dead_currency", 0xFE6F },
+{ "AccessX_Enable", 0xFE70 },
+{ "AccessX_Feedback_Enable", 0xFE71 },
+{ "RepeatKeys_Enable", 0xFE72 },
+{ "SlowKeys_Enable", 0xFE73 },
+{ "BounceKeys_Enable", 0xFE74 },
+{ "StickyKeys_Enable", 0xFE75 },
+{ "MouseKeys_Enable", 0xFE76 },
+{ "MouseKeys_Accel_Enable", 0xFE77 },
+{ "Overlay1_Enable", 0xFE78 },
+{ "Overlay2_Enable", 0xFE79 },
+{ "AudibleBell_Enable", 0xFE7A },
+{ "dead_a", 0xFE80 },
+{ "dead_A", 0xFE81 },
+{ "dead_e", 0xFE82 },
+{ "dead_E", 0xFE83 },
+{ "dead_i", 0xFE84 },
+{ "dead_I", 0xFE85 },
+{ "dead_o", 0xFE86 },
+{ "dead_O", 0xFE87 },
+{ "dead_u", 0xFE88 },
+{ "dead_U", 0xFE89 },
+{ "dead_schwa", 0xFE8A },
+#ifndef TK_NO_DEPRECATED
+{ "dead_small_schwa", 0xFE8A },
+#endif
+{ "dead_SCHWA", 0xFE8B },
+#ifndef TK_NO_DEPRECATED
+{ "dead_capital_schwa", 0xFE8B },
+#endif
+{ "dead_greek", 0xFE8C },
+{ "dead_hamza", 0xFE8D },
+{ "dead_lowline", 0xFE90 },
+{ "dead_aboveverticalline", 0xFE91 },
+{ "dead_belowverticalline", 0xFE92 },
+{ "dead_longsolidusoverlay", 0xFE93 },
+{ "ch", 0xFEA0 },
+{ "Ch", 0xFEA1 },
+{ "CH", 0xFEA2 },
+{ "c_h", 0xFEA3 },
+{ "C_h", 0xFEA4 },
+{ "C_H", 0xFEA5 },
+{ "First_Virtual_Screen", 0xFED0 },
+{ "Prev_Virtual_Screen", 0xFED1 },
+{ "Next_Virtual_Screen", 0xFED2 },
+{ "Last_Virtual_Screen", 0xFED4 },
+{ "Terminate_Server", 0xFED5 },
+{ "Pointer_Left", 0xFEE0 },
+{ "Pointer_Right", 0xFEE1 },
+{ "Pointer_Up", 0xFEE2 },
+{ "Pointer_Down", 0xFEE3 },
+{ "Pointer_UpLeft", 0xFEE4 },
+{ "Pointer_UpRight", 0xFEE5 },
+{ "Pointer_DownLeft", 0xFEE6 },
+{ "Pointer_DownRight", 0xFEE7 },
+{ "Pointer_Button_Dflt", 0xFEE8 },
+{ "Pointer_Button1", 0xFEE9 },
+{ "Pointer_Button2", 0xFEEA },
+{ "Pointer_Button3", 0xFEEB },
+{ "Pointer_Button4", 0xFEEC },
+{ "Pointer_Button5", 0xFEED },
+{ "Pointer_DblClick_Dflt", 0xFEEE },
+{ "Pointer_DblClick1", 0xFEEF },
+{ "Pointer_DblClick2", 0xFEF0 },
+{ "Pointer_DblClick3", 0xFEF1 },
+{ "Pointer_DblClick4", 0xFEF2 },
+{ "Pointer_DblClick5", 0xFEF3 },
+{ "Pointer_Drag_Dflt", 0xFEF4 },
+{ "Pointer_Drag1", 0xFEF5 },
+{ "Pointer_Drag2", 0xFEF6 },
+{ "Pointer_Drag3", 0xFEF7 },
+{ "Pointer_Drag4", 0xFEF8 },
+{ "Pointer_EnableKeys", 0xFEF9 },
+{ "Pointer_Accelerate", 0xFEFA },
+{ "Pointer_DfltBtnNext", 0xFEFB },
+{ "Pointer_DfltBtnPrev", 0xFEFC },
+{ "Pointer_Drag5", 0xFEFD },
 { "space", 0x20 },
+#ifndef TK_NO_DEPRECATED
 { "exclam", 0x21 },
+#endif
 { "quotedbl", 0x22 },
 { "numbersign", 0x23 },
 { "dollar", 0x24 },
+#ifndef TK_NO_DEPRECATED
 { "percent", 0x25 },
 { "ampersand", 0x26 },
 { "apostrophe", 0x27 },
@@ -192,7 +435,9 @@
 { "asterisk", 0x2A },
 { "plus", 0x2B },
 { "comma", 0x2C },
+#endif
 { "minus", 0x2D },
+#ifndef TK_NO_DEPRECATED
 { "period", 0x2E },
 { "slash", 0x2F },
 { "0", 0x30 },
@@ -206,10 +451,14 @@
 { "8", 0x38 },
 { "9", 0x39 },
 { "colon", 0x3A },
+#endif
 { "semicolon", 0x3B },
 { "less", 0x3C },
+#ifndef TK_NO_DEPRECATED
 { "equal", 0x3D },
+#endif
 { "greater", 0x3E },
+#ifndef TK_NO_DEPRECATED
 { "question", 0x3F },
 { "at", 0x40 },
 { "A", 0x41 },
@@ -238,9 +487,11 @@
 { "X", 0x58 },
 { "Y", 0x59 },
 { "Z", 0x5A },
+#endif
 { "bracketleft", 0x5B },
 { "backslash", 0x5C },
 { "bracketright", 0x5D },
+#ifndef TK_NO_DEPRECATED
 { "asciicircum", 0x5E },
 { "underscore", 0x5F },
 { "grave", 0x60 },
@@ -271,11 +522,17 @@
 { "x", 0x78 },
 { "y", 0x79 },
 { "z", 0x7A },
+#endif
 { "braceleft", 0x7B },
+#ifndef TK_NO_DEPRECATED
 { "bar", 0x7C },
+#endif
 { "braceright", 0x7D },
+#ifndef TK_NO_DEPRECATED
 { "asciitilde", 0x7E },
+#endif
 { "nobreakspace", 0xA0 },
+#ifndef TK_NO_DEPRECATED
 { "exclamdown", 0xA1 },
 { "cent", 0xA2 },
 { "sterling", 0xA3 },
@@ -286,6 +543,7 @@
 { "diaeresis", 0xA8 },
 { "copyright", 0xA9 },
 { "ordfeminine", 0xAA },
+{ "guillemetleft", 0xAB },
 { "guillemotleft", 0xAB },
 { "notsign", 0xAC },
 { "hyphen", 0xAD },
@@ -301,7 +559,9 @@
 { "periodcentered", 0xB7 },
 { "cedilla", 0xB8 },
 { "onesuperior", 0xB9 },
+{ "ordmasculine", 0xBA },
 { "masculine", 0xBA },
+{ "guillemetright", 0xBB },
 { "guillemotright", 0xBB },
 { "onequarter", 0xBC },
 { "onehalf", 0xBD },
@@ -333,7 +593,9 @@
 { "Odiaeresis", 0xD6 },
 { "multiply", 0xD7 },
 { "Oslash", 0xD8 },
+#ifndef TK_NO_DEPRECATED
 { "Ooblique", 0xD8 },
+#endif
 { "Ugrave", 0xD9 },
 { "Uacute", 0xDA },
 { "Ucircumflex", 0xDB },
@@ -367,6 +629,9 @@
 { "odiaeresis", 0xF6 },
 { "division", 0xF7 },
 { "oslash", 0xF8 },
+#ifndef TK_NO_DEPRECATED
+{ "ooblique", 0xF8 },
+#endif
 { "ugrave", 0xF9 },
 { "uacute", 0xFA },
 { "ucircumflex", 0xFB },
@@ -374,6 +639,7 @@
 { "yacute", 0xFD },
 { "thorn", 0xFE },
 { "ydiaeresis", 0xFF },
+#endif
 { "Aogonek", 0x1A1 },
 { "breve", 0x1A2 },
 { "Lstroke", 0x1A3 },
@@ -454,7 +720,9 @@
 { "ubreve", 0x2FD },
 { "scircumflex", 0x2FE },
 { "kra", 0x3A2 },
+#ifndef TK_NO_DEPRECATED
 { "kappa", 0x3A2 },
+#endif
 { "Rcedilla", 0x3A3 },
 { "Itilde", 0x3A5 },
 { "Lcedilla", 0x3A6 },
@@ -466,7 +734,9 @@
 { "lcedilla", 0x3B6 },
 { "emacron", 0x3BA },
 { "gcedilla", 0x3BB },
+#ifndef TK_NO_DEPRECATED
 { "gacute", 0x3BB },
+#endif
 { "tslash", 0x3BC },
 { "ENG", 0x3BD },
 { "eng", 0x3BF },
@@ -490,13 +760,18 @@
 { "uogonek", 0x3F9 },
 { "utilde", 0x3FD },
 { "umacron", 0x3FE },
+{ "OE", 0x13BC },
+{ "oe", 0x13BD },
+{ "Ydiaeresis", 0x13BE },
 { "overline", 0x47E },
 { "kana_fullstop", 0x4A1 },
 { "kana_openingbracket", 0x4A2 },
 { "kana_closingbracket", 0x4A3 },
 { "kana_comma", 0x4A4 },
 { "kana_conjunctive", 0x4A5 },
+#ifndef TK_NO_DEPRECATED
 { "kana_middledot", 0x4A5 },
+#endif
 { "kana_WO", 0x4A6 },
 { "kana_a", 0x4A7 },
 { "kana_i", 0x4A8 },
@@ -507,7 +782,9 @@
 { "kana_yu", 0x4AD },
 { "kana_yo", 0x4AE },
 { "kana_tsu", 0x4AF },
+#ifndef TK_NO_DEPRECATED
 { "kana_tu", 0x4AF },
+#endif
 { "prolongedsound", 0x4B0 },
 { "kana_A", 0x4B1 },
 { "kana_I", 0x4B2 },
@@ -526,9 +803,13 @@
 { "kana_SO", 0x4BF },
 { "kana_TA", 0x4C0 },
 { "kana_CHI", 0x4C1 },
+#ifndef TK_NO_DEPRECATED
 { "kana_TI", 0x4C1 },
+#endif
 { "kana_TSU", 0x4C2 },
+#ifndef TK_NO_DEPRECATED
 { "kana_TU", 0x4C2 },
+#endif
 { "kana_TE", 0x4C3 },
 { "kana_TO", 0x4C4 },
 { "kana_NA", 0x4C5 },
@@ -539,7 +820,9 @@
 { "kana_HA", 0x4CA },
 { "kana_HI", 0x4CB },
 { "kana_FU", 0x4CC },
+#ifndef TK_NO_DEPRECATED
 { "kana_HU", 0x4CC },
+#endif
 { "kana_HE", 0x4CD },
 { "kana_HO", 0x4CE },
 { "kana_MA", 0x4CF },
@@ -559,7 +842,6 @@
 { "kana_N", 0x4DD },
 { "voicedsound", 0x4DE },
 { "semivoicedsound", 0x4DF },
-{ "kana_switch", 0xFF7E },
 { "Arabic_comma", 0x5AC },
 { "Arabic_semicolon", 0x5BB },
 { "Arabic_question_mark", 0x5BF },
@@ -597,7 +879,9 @@
 { "Arabic_meem", 0x5E5 },
 { "Arabic_noon", 0x5E6 },
 { "Arabic_ha", 0x5E7 },
+#ifndef TK_NO_DEPRECATED
 { "Arabic_heh", 0x5E7 },
+#endif
 { "Arabic_waw", 0x5E8 },
 { "Arabic_alefmaksura", 0x5E9 },
 { "Arabic_yeh", 0x5EA },
@@ -609,52 +893,79 @@
 { "Arabic_kasra", 0x5F0 },
 { "Arabic_shadda", 0x5F1 },
 { "Arabic_sukun", 0x5F2 },
-{ "Arabic_switch", 0xFF7E },
 { "Serbian_dje", 0x6A1 },
 { "Macedonia_gje", 0x6A2 },
 { "Cyrillic_io", 0x6A3 },
 { "Ukrainian_ie", 0x6A4 },
+#ifndef TK_NO_DEPRECATED
 { "Ukranian_je", 0x6A4 },
+#endif
 { "Macedonia_dse", 0x6A5 },
 { "Ukrainian_i", 0x6A6 },
+#ifndef TK_NO_DEPRECATED
 { "Ukranian_i", 0x6A6 },
+#endif
 { "Ukrainian_yi", 0x6A7 },
+#ifndef TK_NO_DEPRECATED
 { "Ukranian_yi", 0x6A7 },
+#endif
 { "Cyrillic_je", 0x6A8 },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_je", 0x6A8 },
+#endif
 { "Cyrillic_lje", 0x6A9 },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_lje", 0x6A9 },
+#endif
 { "Cyrillic_nje", 0x6AA },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_nje", 0x6AA },
+#endif
 { "Serbian_tshe", 0x6AB },
 { "Macedonia_kje", 0x6AC },
 { "Ukrainian_ghe_with_upturn", 0x6AD },
 { "Byelorussian_shortu", 0x6AE },
 { "Cyrillic_dzhe", 0x6AF },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_dze", 0x6AF },
+#endif
 { "numerosign", 0x6B0 },
 { "Serbian_DJE", 0x6B1 },
 { "Macedonia_GJE", 0x6B2 },
 { "Cyrillic_IO", 0x6B3 },
 { "Ukrainian_IE", 0x6B4 },
+#ifndef TK_NO_DEPRECATED
 { "Ukranian_JE", 0x6B4 },
+#endif
 { "Macedonia_DSE", 0x6B5 },
 { "Ukrainian_I", 0x6B6 },
+#ifndef TK_NO_DEPRECATED
 { "Ukranian_I", 0x6B6 },
+#endif
 { "Ukrainian_YI", 0x6B7 },
+#ifndef TK_NO_DEPRECATED
 { "Ukranian_YI", 0x6B7 },
+#endif
 { "Cyrillic_JE", 0x6B8 },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_JE", 0x6B8 },
+#endif
 { "Cyrillic_LJE", 0x6B9 },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_LJE", 0x6B9 },
+#endif
 { "Cyrillic_NJE", 0x6BA },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_NJE", 0x6BA },
+#endif
 { "Serbian_TSHE", 0x6BB },
 { "Macedonia_KJE", 0x6BC },
 { "Ukrainian_GHE_WITH_UPTURN", 0x6BD },
 { "Byelorussian_SHORTU", 0x6BE },
 { "Cyrillic_DZHE", 0x6BF },
+#ifndef TK_NO_DEPRECATED
 { "Serbian_DZE", 0x6BF },
+#endif
 { "Cyrillic_yu", 0x6C0 },
 { "Cyrillic_a", 0x6C1 },
 { "Cyrillic_be", 0x6C2 },
@@ -724,7 +1035,9 @@
 { "Greek_ETAaccent", 0x7A3 },
 { "Greek_IOTAaccent", 0x7A4 },
 { "Greek_IOTAdieresis", 0x7A5 },
+#ifndef TK_NO_DEPRECATED
 { "Greek_IOTAdiaeresis", 0x7A5 },
+#endif
 { "Greek_IOTAaccentdiaeresis", 0x7A6 },
 { "Greek_OMICRONaccent", 0x7A7 },
 { "Greek_UPSILONaccent", 0x7A8 },
@@ -754,8 +1067,8 @@
 { "Greek_THETA", 0x7C8 },
 { "Greek_IOTA", 0x7C9 },
 { "Greek_KAPPA", 0x7CA },
-{ "Greek_LAMDA", 0x7CB },
 { "Greek_LAMBDA", 0x7CB },
+{ "Greek_LAMDA", 0x7CB },
 { "Greek_MU", 0x7CC },
 { "Greek_NU", 0x7CD },
 { "Greek_XI", 0x7CE },
@@ -779,8 +1092,8 @@
 { "Greek_theta", 0x7E8 },
 { "Greek_iota", 0x7E9 },
 { "Greek_kappa", 0x7EA },
-{ "Greek_lamda", 0x7EB },
 { "Greek_lambda", 0x7EB },
+{ "Greek_lamda", 0x7EB },
 { "Greek_mu", 0x7EC },
 { "Greek_nu", 0x7ED },
 { "Greek_xi", 0x7EE },
@@ -795,7 +1108,6 @@
 { "Greek_chi", 0x7F7 },
 { "Greek_psi", 0x7F8 },
 { "Greek_omega", 0x7F9 },
-{ "Greek_switch", 0xFF7E },
 { "leftradical", 0x8A1 },
 { "topleftradical", 0x8A2 },
 { "horizconnector", 0x8A3 },
@@ -975,19 +1287,31 @@
 { "hebrew_doublelowline", 0xCDF },
 { "hebrew_aleph", 0xCE0 },
 { "hebrew_bet", 0xCE1 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_beth", 0xCE1 },
+#endif
 { "hebrew_gimel", 0xCE2 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_gimmel", 0xCE2 },
+#endif
 { "hebrew_dalet", 0xCE3 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_daleth", 0xCE3 },
+#endif
 { "hebrew_he", 0xCE4 },
 { "hebrew_waw", 0xCE5 },
 { "hebrew_zain", 0xCE6 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_zayin", 0xCE6 },
+#endif
 { "hebrew_chet", 0xCE7 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_het", 0xCE7 },
+#endif
 { "hebrew_tet", 0xCE8 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_teth", 0xCE8 },
+#endif
 { "hebrew_yod", 0xCE9 },
 { "hebrew_finalkaph", 0xCEA },
 { "hebrew_kaph", 0xCEB },
@@ -997,21 +1321,205 @@
 { "hebrew_finalnun", 0xCEF },
 { "hebrew_nun", 0xCF0 },
 { "hebrew_samech", 0xCF1 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_samekh", 0xCF1 },
+#endif
 { "hebrew_ayin", 0xCF2 },
 { "hebrew_finalpe", 0xCF3 },
 { "hebrew_pe", 0xCF4 },
 { "hebrew_finalzade", 0xCF5 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_finalzadi", 0xCF5 },
+#endif
 { "hebrew_zade", 0xCF6 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_zadi", 0xCF6 },
+#endif
 { "hebrew_qoph", 0xCF7 },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_kuf", 0xCF7 },
+#endif
 { "hebrew_resh", 0xCF8 },
 { "hebrew_shin", 0xCF9 },
 { "hebrew_taw", 0xCFA },
+#ifndef TK_NO_DEPRECATED
 { "hebrew_taf", 0xCFA },
-{ "Hebrew_switch", 0xFF7E },
+#endif
+{ "Thai_kokai", 0xDA1 },
+{ "Thai_khokhai", 0xDA2 },
+{ "Thai_khokhuat", 0xDA3 },
+{ "Thai_khokhwai", 0xDA4 },
+{ "Thai_khokhon", 0xDA5 },
+{ "Thai_khorakhang", 0xDA6 },
+{ "Thai_ngongu", 0xDA7 },
+{ "Thai_chochan", 0xDA8 },
+{ "Thai_choching", 0xDA9 },
+{ "Thai_chochang", 0xDAA },
+{ "Thai_soso", 0xDAB },
+{ "Thai_chochoe", 0xDAC },
+{ "Thai_yoying", 0xDAD },
+{ "Thai_dochada", 0xDAE },
+{ "Thai_topatak", 0xDAF },
+{ "Thai_thothan", 0xDB0 },
+{ "Thai_thonangmontho", 0xDB1 },
+{ "Thai_thophuthao", 0xDB2 },
+{ "Thai_nonen", 0xDB3 },
+{ "Thai_dodek", 0xDB4 },
+{ "Thai_totao", 0xDB5 },
+{ "Thai_thothung", 0xDB6 },
+{ "Thai_thothahan", 0xDB7 },
+{ "Thai_thothong", 0xDB8 },
+{ "Thai_nonu", 0xDB9 },
+{ "Thai_bobaimai", 0xDBA },
+{ "Thai_popla", 0xDBB },
+{ "Thai_phophung", 0xDBC },
+{ "Thai_fofa", 0xDBD },
+{ "Thai_phophan", 0xDBE },
+{ "Thai_fofan", 0xDBF },
+{ "Thai_phosamphao", 0xDC0 },
+{ "Thai_moma", 0xDC1 },
+{ "Thai_yoyak", 0xDC2 },
+{ "Thai_rorua", 0xDC3 },
+{ "Thai_ru", 0xDC4 },
+{ "Thai_loling", 0xDC5 },
+{ "Thai_lu", 0xDC6 },
+{ "Thai_wowaen", 0xDC7 },
+{ "Thai_sosala", 0xDC8 },
+{ "Thai_sorusi", 0xDC9 },
+{ "Thai_sosua", 0xDCA },
+{ "Thai_hohip", 0xDCB },
+{ "Thai_lochula", 0xDCC },
+{ "Thai_oang", 0xDCD },
+{ "Thai_honokhuk", 0xDCE },
+{ "Thai_paiyannoi", 0xDCF },
+{ "Thai_saraa", 0xDD0 },
+{ "Thai_maihanakat", 0xDD1 },
+{ "Thai_saraaa", 0xDD2 },
+{ "Thai_saraam", 0xDD3 },
+{ "Thai_sarai", 0xDD4 },
+{ "Thai_saraii", 0xDD5 },
+{ "Thai_saraue", 0xDD6 },
+{ "Thai_sarauee", 0xDD7 },
+{ "Thai_sarau", 0xDD8 },
+{ "Thai_sarauu", 0xDD9 },
+{ "Thai_phinthu", 0xDDA },
+{ "Thai_maihanakat_maitho", 0xDDE },
+{ "Thai_baht", 0xDDF },
+{ "Thai_sarae", 0xDE0 },
+{ "Thai_saraae", 0xDE1 },
+{ "Thai_sarao", 0xDE2 },
+{ "Thai_saraaimaimuan", 0xDE3 },
+{ "Thai_saraaimaimalai", 0xDE4 },
+{ "Thai_lakkhangyao", 0xDE5 },
+{ "Thai_maiyamok", 0xDE6 },
+{ "Thai_maitaikhu", 0xDE7 },
+{ "Thai_maiek", 0xDE8 },
+{ "Thai_maitho", 0xDE9 },
+{ "Thai_maitri", 0xDEA },
+{ "Thai_maichattawa", 0xDEB },
+{ "Thai_thanthakhat", 0xDEC },
+{ "Thai_nikhahit", 0xDED },
+{ "Thai_leksun", 0xDF0 },
+{ "Thai_leknung", 0xDF1 },
+{ "Thai_leksong", 0xDF2 },
+{ "Thai_leksam", 0xDF3 },
+{ "Thai_leksi", 0xDF4 },
+{ "Thai_lekha", 0xDF5 },
+{ "Thai_lekhok", 0xDF6 },
+{ "Thai_lekchet", 0xDF7 },
+{ "Thai_lekpaet", 0xDF8 },
+{ "Thai_lekkao", 0xDF9 },
+{ "Hangul_Kiyeog", 0xEA1 },
+{ "Hangul_SsangKiyeog", 0xEA2 },
+{ "Hangul_KiyeogSios", 0xEA3 },
+{ "Hangul_Nieun", 0xEA4 },
+{ "Hangul_NieunJieuj", 0xEA5 },
+{ "Hangul_NieunHieuh", 0xEA6 },
+{ "Hangul_Dikeud", 0xEA7 },
+{ "Hangul_SsangDikeud", 0xEA8 },
+{ "Hangul_Rieul", 0xEA9 },
+{ "Hangul_RieulKiyeog", 0xEAA },
+{ "Hangul_RieulMieum", 0xEAB },
+{ "Hangul_RieulPieub", 0xEAC },
+{ "Hangul_RieulSios", 0xEAD },
+{ "Hangul_RieulTieut", 0xEAE },
+{ "Hangul_RieulPhieuf", 0xEAF },
+{ "Hangul_RieulHieuh", 0xEB0 },
+{ "Hangul_Mieum", 0xEB1 },
+{ "Hangul_Pieub", 0xEB2 },
+{ "Hangul_SsangPieub", 0xEB3 },
+{ "Hangul_PieubSios", 0xEB4 },
+{ "Hangul_Sios", 0xEB5 },
+{ "Hangul_SsangSios", 0xEB6 },
+{ "Hangul_Ieung", 0xEB7 },
+{ "Hangul_Jieuj", 0xEB8 },
+{ "Hangul_SsangJieuj", 0xEB9 },
+{ "Hangul_Cieuc", 0xEBA },
+{ "Hangul_Khieuq", 0xEBB },
+{ "Hangul_Tieut", 0xEBC },
+{ "Hangul_Phieuf", 0xEBD },
+{ "Hangul_Hieuh", 0xEBE },
+{ "Hangul_A", 0xEBF },
+{ "Hangul_AE", 0xEC0 },
+{ "Hangul_YA", 0xEC1 },
+{ "Hangul_YAE", 0xEC2 },
+{ "Hangul_EO", 0xEC3 },
+{ "Hangul_E", 0xEC4 },
+{ "Hangul_YEO", 0xEC5 },
+{ "Hangul_YE", 0xEC6 },
+{ "Hangul_O", 0xEC7 },
+{ "Hangul_WA", 0xEC8 },
+{ "Hangul_WAE", 0xEC9 },
+{ "Hangul_OE", 0xECA },
+{ "Hangul_YO", 0xECB },
+{ "Hangul_U", 0xECC },
+{ "Hangul_WEO", 0xECD },
+{ "Hangul_WE", 0xECE },
+{ "Hangul_WI", 0xECF },
+{ "Hangul_YU", 0xED0 },
+{ "Hangul_EU", 0xED1 },
+{ "Hangul_YI", 0xED2 },
+{ "Hangul_I", 0xED3 },
+{ "Hangul_J_Kiyeog", 0xED4 },
+{ "Hangul_J_SsangKiyeog", 0xED5 },
+{ "Hangul_J_KiyeogSios", 0xED6 },
+{ "Hangul_J_Nieun", 0xED7 },
+{ "Hangul_J_NieunJieuj", 0xED8 },
+{ "Hangul_J_NieunHieuh", 0xED9 },
+{ "Hangul_J_Dikeud", 0xEDA },
+{ "Hangul_J_Rieul", 0xEDB },
+{ "Hangul_J_RieulKiyeog", 0xEDC },
+{ "Hangul_J_RieulMieum", 0xEDD },
+{ "Hangul_J_RieulPieub", 0xEDE },
+{ "Hangul_J_RieulSios", 0xEDF },
+{ "Hangul_J_RieulTieut", 0xEE0 },
+{ "Hangul_J_RieulPhieuf", 0xEE1 },
+{ "Hangul_J_RieulHieuh", 0xEE2 },
+{ "Hangul_J_Mieum", 0xEE3 },
+{ "Hangul_J_Pieub", 0xEE4 },
+{ "Hangul_J_PieubSios", 0xEE5 },
+{ "Hangul_J_Sios", 0xEE6 },
+{ "Hangul_J_SsangSios", 0xEE7 },
+{ "Hangul_J_Ieung", 0xEE8 },
+{ "Hangul_J_Jieuj", 0xEE9 },
+{ "Hangul_J_Cieuc", 0xEEA },
+{ "Hangul_J_Khieuq", 0xEEB },
+{ "Hangul_J_Tieut", 0xEEC },
+{ "Hangul_J_Phieuf", 0xEED },
+{ "Hangul_J_Hieuh", 0xEEE },
+{ "Hangul_RieulYeorinHieuh", 0xEEF },
+{ "Hangul_SunkyeongeumMieum", 0xEF0 },
+{ "Hangul_SunkyeongeumPieub", 0xEF1 },
+{ "Hangul_PanSios", 0xEF2 },
+{ "Hangul_KkogjiDalrinIeung", 0xEF3 },
+{ "Hangul_SunkyeongeumPhieuf", 0xEF4 },
+{ "Hangul_YeorinHieuh", 0xEF5 },
+{ "Hangul_AraeA", 0xEF6 },
+{ "Hangul_AraeAE", 0xEF7 },
+{ "Hangul_J_PanSios", 0xEF8 },
+{ "Hangul_J_KkogjiDalrinIeung", 0xEF9 },
+{ "Hangul_J_YeorinHieuh", 0xEFA },
+{ "Korean_Won", 0xEFF },
 { "XF86ModeLock", 0x1008FF01 },
 { "XF86MonBrightnessUp", 0x1008FF02 },
 { "XF86MonBrightnessDown", 0x1008FF03 },
@@ -1177,6 +1685,7 @@
 { "XF86RFKill", 0x1008FFB5 },
 { "XF86AudioPreset", 0x1008FFB6 },
 { "XF86RotationLockToggle", 0x1008FFB7 },
+{ "XF86FullScreen", 0x1008FFB8 },
 { "XF86Switch_VT_1", 0x1008FE01 },
 { "XF86Switch_VT_2", 0x1008FE02 },
 { "XF86Switch_VT_3", 0x1008FE03 },
@@ -1195,3 +1704,165 @@
 { "XF86Prev_VMode", 0x1008FE23 },
 { "XF86LogWindowTree", 0x1008FE24 },
 { "XF86LogGrabInfo", 0x1008FE25 },
+{ "XF86BrightnessAuto", 0x100810F4 },
+{ "XF86DisplayOff", 0x100810F5 },
+{ "XF86Info", 0x10081166 },
+{ "XF86AspectRatio", 0x10081177 },
+{ "XF86DVD", 0x10081185 },
+{ "XF86Audio", 0x10081188 },
+{ "XF86ChannelUp", 0x10081192 },
+{ "XF86ChannelDown", 0x10081193 },
+{ "XF86Break", 0x1008119B },
+{ "XF86VideoPhone", 0x100811A0 },
+{ "XF86ZoomReset", 0x100811A4 },
+{ "XF86Editor", 0x100811A6 },
+{ "XF86GraphicsEditor", 0x100811A8 },
+{ "XF86Presentation", 0x100811A9 },
+{ "XF86Database", 0x100811AA },
+{ "XF86Voicemail", 0x100811AC },
+{ "XF86Addressbook", 0x100811AD },
+{ "XF86DisplayToggle", 0x100811AF },
+{ "XF86SpellCheck", 0x100811B0 },
+{ "XF86ContextMenu", 0x100811B6 },
+{ "XF86MediaRepeat", 0x100811B7 },
+{ "XF8610ChannelsUp", 0x100811B8 },
+{ "XF8610ChannelsDown", 0x100811B9 },
+{ "XF86Images", 0x100811BA },
+{ "XF86NotificationCenter", 0x100811BC },
+{ "XF86PickupPhone", 0x100811BD },
+{ "XF86HangupPhone", 0x100811BE },
+{ "XF86Fn", 0x100811D0 },
+{ "XF86Fn_Esc", 0x100811D1 },
+{ "XF86FnRightShift", 0x100811E5 },
+{ "XF86Numeric0", 0x10081200 },
+{ "XF86Numeric1", 0x10081201 },
+{ "XF86Numeric2", 0x10081202 },
+{ "XF86Numeric3", 0x10081203 },
+{ "XF86Numeric4", 0x10081204 },
+{ "XF86Numeric5", 0x10081205 },
+{ "XF86Numeric6", 0x10081206 },
+{ "XF86Numeric7", 0x10081207 },
+{ "XF86Numeric8", 0x10081208 },
+{ "XF86Numeric9", 0x10081209 },
+{ "XF86NumericStar", 0x1008120A },
+{ "XF86NumericPound", 0x1008120B },
+{ "XF86NumericA", 0x1008120C },
+{ "XF86NumericB", 0x1008120D },
+{ "XF86NumericC", 0x1008120E },
+{ "XF86NumericD", 0x1008120F },
+{ "XF86CameraFocus", 0x10081210 },
+{ "XF86WPSButton", 0x10081211 },
+{ "XF86CameraZoomIn", 0x10081215 },
+{ "XF86CameraZoomOut", 0x10081216 },
+{ "XF86CameraUp", 0x10081217 },
+{ "XF86CameraDown", 0x10081218 },
+{ "XF86CameraLeft", 0x10081219 },
+{ "XF86CameraRight", 0x1008121A },
+{ "XF86AttendantOn", 0x1008121B },
+{ "XF86AttendantOff", 0x1008121C },
+{ "XF86AttendantToggle", 0x1008121D },
+{ "XF86LightsToggle", 0x1008121E },
+{ "XF86ALSToggle", 0x10081230 },
+{ "XF86Buttonconfig", 0x10081240 },
+{ "XF86Taskmanager", 0x10081241 },
+{ "XF86Journal", 0x10081242 },
+{ "XF86ControlPanel", 0x10081243 },
+{ "XF86AppSelect", 0x10081244 },
+{ "XF86Screensaver", 0x10081245 },
+{ "XF86VoiceCommand", 0x10081246 },
+{ "XF86Assistant", 0x10081247 },
+{ "XF86EmojiPicker", 0x10081249 },
+{ "XF86Dictate", 0x1008124A },
+{ "XF86BrightnessMin", 0x10081250 },
+{ "XF86BrightnessMax", 0x10081251 },
+{ "XF86KbdInputAssistPrev", 0x10081260 },
+{ "XF86KbdInputAssistNext", 0x10081261 },
+{ "XF86KbdInputAssistPrevgroup", 0x10081262 },
+{ "XF86KbdInputAssistNextgroup", 0x10081263 },
+{ "XF86KbdInputAssistAccept", 0x10081264 },
+{ "XF86KbdInputAssistCancel", 0x10081265 },
+{ "XF86RightUp", 0x10081266 },
+{ "XF86RightDown", 0x10081267 },
+{ "XF86LeftUp", 0x10081268 },
+{ "XF86LeftDown", 0x10081269 },
+{ "XF86RootMenu", 0x1008126A },
+{ "XF86MediaTopMenu", 0x1008126B },
+{ "XF86Numeric11", 0x1008126C },
+{ "XF86Numeric12", 0x1008126D },
+{ "XF86AudioDesc", 0x1008126E },
+{ "XF863DMode", 0x1008126F },
+{ "XF86NextFavorite", 0x10081270 },
+{ "XF86StopRecord", 0x10081271 },
+{ "XF86PauseRecord", 0x10081272 },
+{ "XF86VOD", 0x10081273 },
+{ "XF86Unmute", 0x10081274 },
+{ "XF86FastReverse", 0x10081275 },
+{ "XF86SlowReverse", 0x10081276 },
+{ "XF86Data", 0x10081277 },
+{ "XF86OnScreenKeyboard", 0x10081278 },
+{ "XF86PrivacyScreenToggle", 0x10081279 },
+{ "XF86SelectiveScreenshot", 0x1008127A },
+{ "XF86Macro1", 0x10081290 },
+{ "XF86Macro2", 0x10081291 },
+{ "XF86Macro3", 0x10081292 },
+{ "XF86Macro4", 0x10081293 },
+{ "XF86Macro5", 0x10081294 },
+{ "XF86Macro6", 0x10081295 },
+{ "XF86Macro7", 0x10081296 },
+{ "XF86Macro8", 0x10081297 },
+{ "XF86Macro9", 0x10081298 },
+{ "XF86Macro10", 0x10081299 },
+{ "XF86Macro11", 0x1008129A },
+{ "XF86Macro12", 0x1008129B },
+{ "XF86Macro13", 0x1008129C },
+{ "XF86Macro14", 0x1008129D },
+{ "XF86Macro15", 0x1008129E },
+{ "XF86Macro16", 0x1008129F },
+{ "XF86Macro17", 0x100812A0 },
+{ "XF86Macro18", 0x100812A1 },
+{ "XF86Macro19", 0x100812A2 },
+{ "XF86Macro20", 0x100812A3 },
+{ "XF86Macro21", 0x100812A4 },
+{ "XF86Macro22", 0x100812A5 },
+{ "XF86Macro23", 0x100812A6 },
+{ "XF86Macro24", 0x100812A7 },
+{ "XF86Macro25", 0x100812A8 },
+{ "XF86Macro26", 0x100812A9 },
+{ "XF86Macro27", 0x100812AA },
+{ "XF86Macro28", 0x100812AB },
+{ "XF86Macro29", 0x100812AC },
+{ "XF86Macro30", 0x100812AD },
+{ "XF86MacroRecordStart", 0x100812B0 },
+{ "XF86MacroRecordStop", 0x100812B1 },
+{ "XF86MacroPresetCycle", 0x100812B2 },
+{ "XF86MacroPreset1", 0x100812B3 },
+{ "XF86MacroPreset2", 0x100812B4 },
+{ "XF86MacroPreset3", 0x100812B5 },
+{ "XF86KbdLcdMenu1", 0x100812B8 },
+{ "XF86KbdLcdMenu2", 0x100812B9 },
+{ "XF86KbdLcdMenu3", 0x100812BA },
+{ "XF86KbdLcdMenu4", 0x100812BB },
+{ "XF86KbdLcdMenu5", 0x100812BC },
+{ "SunFA_Grave", 0x1005FF00 },
+{ "SunFA_Circum", 0x1005FF01 },
+{ "SunFA_Tilde", 0x1005FF02 },
+{ "SunFA_Acute", 0x1005FF03 },
+{ "SunFA_Diaeresis", 0x1005FF04 },
+{ "SunFA_Cedilla", 0x1005FF05 },
+{ "SunF36", 0x1005FF10 },
+{ "SunF37", 0x1005FF11 },
+{ "SunSys_Req", 0x1005FF60 },
+{ "SunProps", 0x1005FF70 },
+{ "SunFront", 0x1005FF71 },
+{ "SunCopy", 0x1005FF72 },
+{ "SunOpen", 0x1005FF73 },
+{ "SunPaste", 0x1005FF74 },
+{ "SunCut", 0x1005FF75 },
+{ "SunPowerSwitch", 0x1005FF76 },
+{ "SunAudioLowerVolume", 0x1005FF77 },
+{ "SunAudioMute", 0x1005FF78 },
+{ "SunAudioRaiseVolume", 0x1005FF79 },
+{ "SunVideoDegauss", 0x1005FF7A },
+{ "SunVideoLowerBrightness", 0x1005FF7B },
+{ "SunVideoRaiseBrightness", 0x1005FF7C },
+{ "SunPowerSwitchShift", 0x1005FF7D },
