@@ -823,11 +823,7 @@ FrameWidgetObjCmd(
 
 static void
 DestroyFrame(
-#if TCL_MAJOR_VERSION > 8
     void *memPtr)		/* Info about frame widget. */
-#else
-    char *memPtr)
-#endif
 {
     Frame *framePtr = (Frame *)memPtr;
     Labelframe *labelframePtr = (Labelframe *)memPtr;
@@ -986,11 +982,11 @@ ConfigureFrame(
 	Tk_SetWindowBackgroundPixmap(framePtr->tkwin, None);
     }
 
-    Tk_GetPixelsFromObj(NULL, framePtr->tkwin, framePtr->widthObj, &width);
-    if (width < 0) {
-	Tcl_DecrRefCount(framePtr->widthObj);
-	framePtr->widthObj = Tcl_NewIntObj(0);
-	Tcl_IncrRefCount(framePtr->widthObj);
+    Tk_GetPixelsFromObj(NULL, framePtr->tkwin, framePtr->borderWidthObj, &borderWidth);
+    if (borderWidth < 0) {
+	Tcl_DecrRefCount(framePtr->borderWidthObj);
+	framePtr->borderWidthObj = Tcl_NewIntObj(0);
+	Tcl_IncrRefCount(framePtr->borderWidthObj);
     }
     Tk_GetPixelsFromObj(NULL, framePtr->tkwin, framePtr->heightObj, &height);
     if (height < 0) {
@@ -998,12 +994,6 @@ ConfigureFrame(
 	framePtr->heightObj = Tcl_NewIntObj(0);
 	Tcl_IncrRefCount(framePtr->heightObj);
     }
-    Tk_GetPixelsFromObj(NULL, framePtr->tkwin, framePtr->borderWidthObj, &borderWidth);
-    if (borderWidth < 0) {
-	Tcl_DecrRefCount(framePtr->borderWidthObj);
-	framePtr->borderWidthObj = Tcl_NewIntObj(0);
-	Tcl_IncrRefCount(framePtr->borderWidthObj);
-    }
     Tk_GetPixelsFromObj(NULL, framePtr->tkwin, framePtr->highlightWidthObj, &highlightWidth);
     if (highlightWidth < 0) {
 	Tcl_DecrRefCount(framePtr->highlightWidthObj);
@@ -1022,6 +1012,12 @@ ConfigureFrame(
 	framePtr->padYObj = Tcl_NewIntObj(0);
 	Tcl_IncrRefCount(framePtr->padYObj);
     }
+    Tk_GetPixelsFromObj(NULL, framePtr->tkwin, framePtr->widthObj, &width);
+    if (width < 0) {
+	Tcl_DecrRefCount(framePtr->widthObj);
+	framePtr->widthObj = Tcl_NewIntObj(0);
+	Tcl_IncrRefCount(framePtr->widthObj);
+    }
 
     /*
      * If a -labelwidget is specified, check that it is valid and set up
