@@ -4,8 +4,8 @@
  *	This file maintains a database of read-only graphics contexts for the
  *	Tk toolkit, in order to allow GC's to be shared.
  *
- * Copyright (c) 1990-1994 The Regents of the University of California.
- * Copyright (c) 1994 Sun Microsystems, Inc.
+ * Copyright © 1990-1994 The Regents of the University of California.
+ * Copyright © 1994 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -23,7 +23,7 @@
 typedef struct {
     GC gc;			/* Graphics context. */
     Display *display;		/* Display to which gc belongs. */
-    int refCount;		/* Number of active uses of gc. */
+    size_t refCount;		/* Number of active uses of gc. */
     Tcl_HashEntry *valueHashPtr;/* Entry in valueTable (needed when deleting
 				 * this structure). */
 } TkGC;
@@ -307,7 +307,7 @@ Tk_FreeGC(
 	return;
     }
 
-    idHashPtr = Tcl_FindHashEntry(&dispPtr->gcIdTable, (char *) gc);
+    idHashPtr = Tcl_FindHashEntry(&dispPtr->gcIdTable, gc);
     if (idHashPtr == NULL) {
 	Tcl_Panic("Tk_FreeGC received unknown gc argument");
     }
