@@ -3,7 +3,7 @@
  *
  *	This file contains image related utility functions.
  *
- * Copyright (c) 1995 Sun Microsystems, Inc.
+ * Copyright © 1995 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -11,7 +11,9 @@
 
 #include "tkInt.h"
 #include "xbytes.h"
-
+#ifdef _WIN32
+#   include "tkWinInt.h"
+#endif
 
 /*
  *----------------------------------------------------------------------
@@ -55,7 +57,7 @@ TkAlignImageData(
 	dataWidth += (alignment - (dataWidth % alignment));
     }
 
-    data = ckalloc((unsigned) dataWidth * image->height);
+    data = (char *)ckalloc(dataWidth * image->height);
 
     destPtr = data;
     for (i = 0; i < image->height; i++) {
