@@ -68,7 +68,7 @@ typedef struct TkMenuEntry {
     int state;			/* State of button for display purposes:
 				 * normal, active, or disabled. */
     int underline;		/* Value of -underline option: specifies index
-				 * of character to underline (-1 means don't
+				 * of character to underline (INT_MIN means don't
 				 * underline anything). */
     Tcl_Obj *underlinePtr;	/* Index of character to underline. */
     Tcl_Obj *bitmapPtr;		/* Bitmap to display in menu entry, or NULL.
@@ -116,15 +116,15 @@ typedef struct TkMenuEntry {
 				 * always 0 for tearoff and separator
 				 * entries. */
     int hideMargin;		/* If this is 0, then the item has enough
-    				 * margin to accommodate a standard check mark
-    				 * and a default right margin. If this is 1,
-    				 * then the item has no such margins, and
-    				 * checkbuttons and radiobuttons with this set
-    				 * will have a rectangle drawn in the
-    				 * indicator around the item if the item is
-    				 * checked. This is useful for palette menus.
-    				 * This field is ignored for separators and
-    				 * tearoffs. */
+				 * margin to accommodate a standard check mark
+				 * and a default right margin. If this is 1,
+				 * then the item has no such margins, and
+				 * checkbuttons and radiobuttons with this set
+				 * will have a rectangle drawn in the
+				 * indicator around the item if the item is
+				 * checked. This is useful for palette menus.
+				 * This field is ignored for separators and
+				 * tearoffs. */
     int indicatorSpace;		/* The width of the indicator space for this
 				 * entry. */
     int labelWidth;		/* Number of pixels to allow for displaying
@@ -181,29 +181,33 @@ typedef struct TkMenuEntry {
     int entryFlags;		/* Various flags. See below for
 				 * definitions. */
     int index;			/* Need to know which index we are. This is
-    				 * zero-based. This is the top-left entry of
-    				 * the menu. */
+				 * zero-based. This is the top-left entry of
+				 * the menu. */
+#if TK_MAJOR_VERSION > 8
     Tcl_HashEntry *entryPtr;	/* Back-pointer to hash table entry */
-
+#endif
     /*
      * Bookeeping for main menus and cascade menus.
      */
 
     struct TkMenuReferences *childMenuRefPtr;
-    				/* A pointer to the hash table entry for the
-    				 * child menu. Stored here when the menu entry
-    				 * is configured so that a hash lookup is not
-    				 * necessary later.*/
+				/* A pointer to the hash table entry for the
+				 * child menu. Stored here when the menu entry
+				 * is configured so that a hash lookup is not
+				 * necessary later.*/
     struct TkMenuEntry *nextCascadePtr;
-    				/* The next cascade entry that is a parent of
-    				 * this entry's child cascade menu. NULL end
-    				 * of list, this is not a cascade entry, or
-    				 * the menu that this entry point to does not
-    				 * yet exist. */
+				/* The next cascade entry that is a parent of
+				 * this entry's child cascade menu. NULL end
+				 * of list, this is not a cascade entry, or
+				 * the menu that this entry point to does not
+				 * yet exist. */
     TkMenuPlatformEntryData platformEntryData;
-    				/* The data for the specific type of menu.
+				/* The data for the specific type of menu.
 				 * Depends on platform and menu type what kind
 				 * of options are in this structure. */
+#if TK_MAJOR_VERSION < 9
+    Tcl_HashEntry *entryPtr;	/* Back-pointer to hash table entry */
+#endif
 } TkMenuEntry;
 
 /*
@@ -268,7 +272,7 @@ typedef struct TkMenu {
     Tcl_Size active;			/* Index of active entry. TCL_INDEX_NONE means
 				 * nothing active. */
     int menuType;		/* MAIN_MENU, TEAROFF_MENU, or MENUBAR. See
-    				 * below for definitions. */
+				 * below for definitions. */
     Tcl_Obj *menuTypePtr;	/* Used to control whether created tkwin is a
 				 * toplevel or not. "normal", "menubar", or
 				 * "toplevel" */
@@ -279,12 +283,20 @@ typedef struct TkMenu {
 
     Tcl_Obj *borderPtr;		/* Structure used to draw 3-D border and
 				 * background for menu. */
+#if TK_MAJOR_VERSION > 8
     Tcl_Obj *borderWidthObj;	/* Width of border around whole menu. */
+#else
+    Tcl_Obj *borderWidthPtr;
+#endif
     Tcl_Obj *activeBorderPtr;	/* Used to draw background and border for
 				 * active element (if any). */
     Tcl_Obj *activeBorderWidthPtr;
 				/* Width of border around active element. */
+#if TK_MAJOR_VERSION > 8
     int relief;		/* 3-d effect: TK_RELIEF_RAISED, etc. */
+#else
+    Tcl_Obj *reliefPtr;
+#endif
     Tcl_Obj *fontPtr;		/* Text font for menu entries. */
     Tcl_Obj *fgPtr;		/* Foreground color for entries. */
     Tcl_Obj *disabledFgPtr;	/* Foreground color when disabled. NULL means
@@ -322,16 +334,16 @@ typedef struct TkMenu {
      */
 
     int tearoff;		/* 1 means this menu can be torn off. On some
-    				 * platforms, the user can drag an outline of
-    				 * the menu by just dragging outside of the
-    				 * menu, and the tearoff is created where the
-    				 * mouse is released. On others, an indicator
-    				 * (such as a dashed stripe) is drawn, and
-    				 * when the menu is selected, the tearoff is
-    				 * created. */
+				 * platforms, the user can drag an outline of
+				 * the menu by just dragging outside of the
+				 * menu, and the tearoff is created where the
+				 * mouse is released. On others, an indicator
+				 * (such as a dashed stripe) is drawn, and
+				 * when the menu is selected, the tearoff is
+				 * created. */
     Tcl_Obj *titlePtr;		/* The title to use when this menu is torn
-    				 * off. If this is NULL, a default scheme will
-    				 * be used to generate a title for tearoff. */
+				 * off. If this is NULL, a default scheme will
+				 * be used to generate a title for tearoff. */
     Tcl_Obj *tearoffCommandPtr;	/* If non-NULL, points to a command to run
 				 * whenever the menu is torn-off. */
     Tcl_Obj *takeFocusPtr;	/* Value of -takefocus option; not used in the
@@ -339,9 +351,9 @@ typedef struct TkMenu {
 				 * scripts. Malloc'ed, but may be NULL. */
     Tcl_Obj *cursorPtr;		/* Current cursor for window, or NULL. */
     Tcl_Obj *postCommandPtr;	/* Used to detect cycles in cascade hierarchy
-    				 * trees when preprocessing postcommands on
-    				 * some platforms. See PostMenu for more
-    				 * details. */
+				 * trees when preprocessing postcommands on
+				 * some platforms. See PostMenu for more
+				 * details. */
     int postCommandGeneration;	/* Need to do pre-invocation post command
 				 * traversal. */
     int menuFlags;		/* Flags for use by X; see below for
@@ -350,25 +362,25 @@ typedef struct TkMenu {
 				 * that is currently posted or NULL if no
 				 * submenu posted. */
     struct TkMenu *nextInstancePtr;
-    				/* The next instance of this menu in the
-    				 * chain. */
+				/* The next instance of this menu in the
+				 * chain. */
     struct TkMenu *mainMenuPtr;
-    				/* A pointer to the original menu for this
-    				 * clone chain. Points back to this structure
-    				 * if this menu is a main menu. */
+				/* A pointer to the original menu for this
+				 * clone chain. Points back to this structure
+				 * if this menu is a main menu. */
     void *reserved1; /* not used any more. */
     Tk_Window parentTopLevelPtr;/* If this menu is a menubar, this is the
-    				 * toplevel that owns the menu. Only
-    				 * applicable for menubar clones. */
+				 * toplevel that owns the menu. Only
+				 * applicable for menubar clones. */
     struct TkMenuReferences *menuRefPtr;
-    				/* Each menu is hashed into a table with the
-    				 * name of the menu's window as the key. The
-    				 * information in this hash table includes a
-    				 * pointer to the menu (so that cascades can
-    				 * find this menu), a pointer to the list of
-    				 * toplevel widgets that have this menu as its
-    				 * menubar, and a list of menu entries that
-    				 * have this menu specified as a cascade. */
+				/* Each menu is hashed into a table with the
+				 * name of the menu's window as the key. The
+				 * information in this hash table includes a
+				 * pointer to the menu (so that cascades can
+				 * find this menu), a pointer to the list of
+				 * toplevel widgets that have this menu as its
+				 * menubar, and a list of menu entries that
+				 * have this menu specified as a cascade. */
     TkMenuPlatformData platformData;
 				/* The data for the specific type of menu.
 				 * Depends on platform and menu type what kind
@@ -379,7 +391,7 @@ typedef struct TkMenu {
 				/* We actually have to allocate these because
 				 * multiple menus get changed during one
 				 * ConfigureMenu call. */
-    Tcl_Obj *activeReliefPtr;	/* 3-d effect for active element. */
+    int activeRelief;	/* 3-d effect for active element. */
     Tcl_HashTable items;	/* Map: id -> entry */
     int serial;			/* Next item # for autogenerated ids */
 } TkMenu;
@@ -392,7 +404,7 @@ typedef struct TkMenu {
 
 typedef struct TkMenuTopLevelList {
     struct TkMenuTopLevelList *nextPtr;
-    				/* The next window in the list. */
+				/* The next window in the list. */
     Tk_Window tkwin;		/* The window that has this menu as its
 				 * menubar. */
 } TkMenuTopLevelList;
@@ -413,18 +425,18 @@ typedef struct TkMenuTopLevelList {
 
 typedef struct TkMenuReferences {
     struct TkMenu *menuPtr;	/* The menu data structure. This is NULL if
-    				 * the menu does not exist. */
+				 * the menu does not exist. */
     TkMenuTopLevelList *topLevelListPtr;
-    				/* First in the list of all toplevels that
-    				 * have this menu as its menubar. NULL if no
-    				 * toplevel widgets have this menu as its
-    				 * menubar. */
+				/* First in the list of all toplevels that
+				 * have this menu as its menubar. NULL if no
+				 * toplevel widgets have this menu as its
+				 * menubar. */
     TkMenuEntry *parentEntryPtr;/* First in the list of all cascade menu
-    				 * entries that have this menu as their child.
-    				 * NULL means no cascade entries. */
+				 * entries that have this menu as their child.
+				 * NULL means no cascade entries. */
     Tcl_HashEntry *hashEntryPtr;/* This is needed because the pathname of the
-    				 * window (which is what we hash on) may not
-    				 * be around when we are deleting. */
+				 * window (which is what we hash on) may not
+				 * be around when we are deleting. */
 } TkMenuReferences;
 
 /*
@@ -464,9 +476,9 @@ typedef struct TkMenuReferences {
  */
 
 #define UNKNOWN_TYPE		-1
-#define MENUBAR 		0
-#define MAIN_MENU 		1
-#define TEAROFF_MENU 		2
+#define MENUBAR		0
+#define MAIN_MENU		1
+#define TEAROFF_MENU		2
 
 /*
  * Various geometry definitions:
@@ -504,7 +516,7 @@ MODULE_SCOPE int	TkMenuConfigureEntryDrawOptions(
 MODULE_SCOPE void	TkMenuFreeDrawOptions(TkMenu *menuPtr);
 MODULE_SCOPE void	TkMenuEntryFreeDrawOptions(TkMenuEntry *mePtr);
 MODULE_SCOPE void	TkMenuEventProc(void *clientData,
-    			    XEvent *eventPtr);
+			    XEvent *eventPtr);
 MODULE_SCOPE void	TkMenuImageProc(void *clientData, int x, int y,
 			    int width, int height, int imgWidth,
 			    int imgHeight);
