@@ -414,7 +414,7 @@ DestroyMessage(
  *
  * ConfigureMessage --
  *
- *	This function is called to process an argv/argc list, plus the Tk
+ *	This function is called to process an objv/objc list, plus the Tk
  *	option database, in order to configure (or reconfigure) a message
  *	widget.
  *
@@ -488,27 +488,15 @@ ConfigureMessage(
      * be specified to Tk_ConfigureWidget.
      */
 
-    Tk_GetPixelsFromObj(NULL, msgPtr->tkwin, msgPtr->widthObj, &width);
-    if (width < 0) {
-	if (msgPtr->widthObj) {
-	    Tcl_DecrRefCount(msgPtr->widthObj);
-	}
-	msgPtr->widthObj = Tcl_NewIntObj(0);
-	Tcl_IncrRefCount(msgPtr->widthObj);
-    }
     Tk_GetPixelsFromObj(NULL, msgPtr->tkwin, msgPtr->borderWidthObj, &borderWidth);
     if (borderWidth < 0) {
-	if (msgPtr->borderWidthObj) {
-	    Tcl_DecrRefCount(msgPtr->borderWidthObj);
-	}
+	Tcl_DecrRefCount(msgPtr->borderWidthObj);
 	msgPtr->borderWidthObj = Tcl_NewIntObj(0);
 	Tcl_IncrRefCount(msgPtr->borderWidthObj);
     }
     Tk_GetPixelsFromObj(NULL, msgPtr->tkwin, msgPtr->highlightWidthObj, &highlightWidth);
     if (highlightWidth < 0) {
-	if (msgPtr->highlightWidthObj) {
-	    Tcl_DecrRefCount(msgPtr->highlightWidthObj);
-	}
+	Tcl_DecrRefCount(msgPtr->highlightWidthObj);
 	msgPtr->highlightWidthObj = Tcl_NewIntObj(0);
 	Tcl_IncrRefCount(msgPtr->highlightWidthObj);
     }
@@ -526,6 +514,12 @@ ConfigureMessage(
 	    msgPtr->padYObj = NULL;
 	}
     }
+    Tk_GetPixelsFromObj(NULL, msgPtr->tkwin, msgPtr->widthObj, &width);
+    if (width < 0) {
+	Tcl_DecrRefCount(msgPtr->widthObj);
+	msgPtr->widthObj = Tcl_NewIntObj(0);
+	Tcl_IncrRefCount(msgPtr->widthObj);
+    }
 
     Tk_FreeSavedOptions(&savedOptions);
     MessageWorldChanged(msgPtr);
