@@ -84,7 +84,7 @@ static const char *const alignStrings[] = {
 static const Tk_OptionSpec optionSpecs[] = {
     {TK_OPTION_STRING_TABLE, "-align", NULL, NULL,
 	"center", TCL_INDEX_NONE, offsetof(TkTextEmbImage, align),
-	(TCL_MAJOR_VERSION > 8) ? TK_OPTION_ENUM_VAR : 0, alignStrings, 0},
+	TK_OPTION_ENUM_VAR, alignStrings, 0},
     {TK_OPTION_PIXELS, "-padx", NULL, NULL,
 	"0", offsetof(TkTextEmbImage, padXObj), TCL_INDEX_NONE, 0, 0, 0},
     {TK_OPTION_PIXELS, "-pady", NULL, NULL,
@@ -539,9 +539,19 @@ EmbImageLayoutProc(
 
     if (eiPtr->body.ei.padXObj) {
 	Tk_GetPixelsFromObj(NULL, textPtr->tkwin, eiPtr->body.ei.padXObj, &padX);
+	if (padX < 0) {
+	    Tcl_DecrRefCount(eiPtr->body.ei.padXObj);
+	    eiPtr->body.ei.padXObj = Tcl_NewIntObj(0);
+	    Tcl_IncrRefCount(eiPtr->body.ei.padXObj);
+	}
     }
     if (eiPtr->body.ei.padYObj) {
 	Tk_GetPixelsFromObj(NULL, textPtr->tkwin, eiPtr->body.ei.padYObj, &padY);
+	if (padY < 0) {
+	    Tcl_DecrRefCount(eiPtr->body.ei.padYObj);
+	    eiPtr->body.ei.padYObj = Tcl_NewIntObj(0);
+	    Tcl_IncrRefCount(eiPtr->body.ei.padYObj);
+	}
     }
     /*
      * See if there's room for this image on this line.
