@@ -96,7 +96,7 @@ static const char *const alignStrings[] = {
 static const Tk_OptionSpec optionSpecs[] = {
     {TK_OPTION_STRING_TABLE, "-align", NULL, NULL,
 	"center", TCL_INDEX_NONE, offsetof(TkTextEmbWindow, align),
-	(TCL_MAJOR_VERSION > 8) ? TK_OPTION_ENUM_VAR : 0, alignStrings, 0},
+	TK_OPTION_ENUM_VAR, alignStrings, 0},
     {TK_OPTION_STRING, "-create", NULL, NULL,
 	NULL, offsetof(TkTextEmbWindow, createObj), TCL_INDEX_NONE, TK_OPTION_NULL_OK, 0, 0},
     {TK_OPTION_PIXELS, "-padx", NULL, NULL,
@@ -991,9 +991,11 @@ EmbWinLayoutProc(
     } else {
 	if (ewPtr->body.ew.padXObj) {
 	    Tk_GetPixelsFromObj(NULL, textPtr->tkwin, ewPtr->body.ew.padXObj, &padX);
+
 	}
 	if (ewPtr->body.ew.padYObj) {
 	    Tk_GetPixelsFromObj(NULL, textPtr->tkwin, ewPtr->body.ew.padYObj, &padY);
+
 	}
 	width = Tk_ReqWidth(ewPtr->body.ew.tkwin) + 2 * padX;
 	height = Tk_ReqHeight(ewPtr->body.ew.tkwin) + 2 * padY;
