@@ -7,6 +7,8 @@ if {![info exists widgetDemo]} {
     error "This script should be run from the \"widget\" demo."
 }
 
+package require tk
+
 # bitmapRow --
 # Create a row of bitmap items in a window.
 #
@@ -31,7 +33,6 @@ proc bitmapRow {w args} {
 }
 
 set w .bitmap
-global tk_library
 catch {destroy $w}
 toplevel $w
 wm title $w "Bitmap Demonstration"
@@ -41,11 +42,9 @@ positionWindow $w
 label $w.msg -font $font -wraplength 4i -justify left -text "This window displays all of Tk's built-in bitmaps, along with the names you can use for them in Tcl scripts."
 pack $w.msg -side top
 
-frame $w.buttons
-pack $w.buttons -side bottom -fill x -pady 2m
-button $w.buttons.dismiss -text Dismiss -command "destroy $w"
-button $w.buttons.code -text "See Code" -command "showCode $w"
-pack $w.buttons.dismiss $w.buttons.code -side left -expand 1
+## See Code / Dismiss buttons
+set btns [addSeeDismiss $w.buttons $w]
+pack $btns -side bottom -fill x
 
 frame $w.frame
 bitmapRow $w.frame.0 error gray12 gray25 gray50 gray75
