@@ -5,7 +5,7 @@
  *	the configuration package.
  *
  * Copyright © 1997 Sun Microsystems, Inc.
- * Copyright © 2001, Apple Inc.
+ * Copyright © 2001 Apple Inc.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -17,7 +17,7 @@
 /*
  *----------------------------------------------------------------------
  *
- * TkpGetSystemDefault --
+ * Tk_GetSystemDefault --
  *
  *	Given a dbName and className for a configuration option,
  *	return a string representation of the option.
@@ -34,15 +34,11 @@
  */
 
 Tcl_Obj *
-TkpGetSystemDefault(
-    Tk_Window tkwin,			/* A window to use. */
-    const char *dbName,			/* The option database name. */
-    const char *className)		/* The name of the option class. */
+Tk_GetSystemDefault(
+    TCL_UNUSED(Tk_Window),			/* A window to use. */
+    TCL_UNUSED(const char *),			/* The option database name. */
+    TCL_UNUSED(const char *))		/* The name of the option class. */
 {
-    (void)tkwin;
-    (void)dbName;
-    (void)className;
-
     return NULL;
 }
 
