@@ -39,12 +39,12 @@ static int		GenerateActivateEvents(TkWindow *winPtr,
 
 extern NSString *NSWindowDidOrderOnScreenNotification;
 extern NSString *NSWindowWillOrderOnScreenNotification;
+extern NSString *NSWindowWillCloseNotification;
 
 #ifdef TK_MAC_DEBUG_NOTIFICATIONS
 extern NSString *NSWindowDidOrderOffScreenNotification;
 #endif
 
-
 @implementation TKApplication(TKWindowEvent)
 
 - (void) windowActivation: (NSNotification *) notification
@@ -52,33 +52,81 @@ extern NSString *NSWindowDidOrderOffScreenNotification;
 #ifdef TK_MAC_DEBUG_NOTIFICATIONS
     TKLog(@"-[%@(%p) %s] %@", [self class], self, sel_getName(_cmd), notification);
 #endif
-    NSWindow *w = [notification object];
-    TkWindow *winPtr = TkMacOSXGetTkWindow(w);
+    if ([NSApp tkWillExit]) {
+	return;
+    }
+    static NSWindow *systemDialog = NULL;
+    NSWindow *win = [notification object];
+    TkWindow *winPtr = TkMacOSXGetTkWindow(win);
     NSString *name = [notification name];
-    Bool flag = [name isEqualToString:NSWindowDidBecomeKeyNotification];
-    if (winPtr && flag) {
-	NSPoint location = [NSEvent mouseLocation];
-	int x = location.x;
-	int y = floor(TkMacOSXZeroScreenHeight() - location.y);
-	/*
-	 * The Tk event target persists when there is no key window but
-	 * gets reset when a new window becomes the key window.
-	 */
+    if ([name isEqualToString:NSWindowDidResignKeyNotification]) {
+	if (![NSApp keyWindow] && [NSApp isActive]) {
+	    if (winPtr) {
+		/*
+		 * A Tk window lost focus and no window has focus anymore.
+		 */
 
-	[NSApp setTkEventTarget: winPtr];
+		TkMacOSXAssignNewKeyWindow(Tk_Interp((Tk_Window) winPtr), NULL);
+	    } else {
+		/*
+		 * A system dialog, such as a standard About dialog, lost focus.
+		 */
 
-	/*
-	 * Call Tk_UpdatePointer if the pointer is in the window.
-	 */
-
-	NSView *view = [w contentView];
-	NSPoint viewLocation = [view convertPoint:location fromView:nil];
-	if (NSPointInRect(viewLocation, NSInsetRect([view bounds], 2, 2))) {
-	    Tk_UpdatePointer((Tk_Window) winPtr, x, y, [NSApp tkButtonState]);
+		TkMacOSXAssignNewKeyWindow(NULL, NULL);
+	    }
 	}
     }
-    if (winPtr && Tk_IsMapped(winPtr)) {
-	GenerateActivateEvents(winPtr, flag);
+    /*
+     * On older systems the system dialogs do not send DidResignKey
+     * but the do send WillClose.
+     */
+
+    if ([name isEqualToString:NSWindowWillCloseNotification]) {
+	if (win == systemDialog) {
+	    TkMacOSXAssignNewKeyWindow(NULL, NULL);
+	}
+    }
+    if ([name isEqualToString:NSWindowDidBecomeKeyNotification]) {
+	if (winPtr) {
+	    NSPoint location = [NSEvent mouseLocation];
+	    int x = location.x;
+	    int y = floor(TkMacOSXZeroScreenHeight() - location.y);
+	    /*
+	     * The Tk event target persists when there is no key window but
+	     * gets reset when a new window becomes the key window.
+	     */
+
+	    [NSApp setTkEventTarget: winPtr];
+
+	    /*
+	     * Call Tk_UpdatePointer if the pointer is in the window.
+	     */
+
+	    NSView *view = [win contentView];
+	    NSPoint viewLocation = [view convertPoint:location fromView:nil];
+	    if (NSPointInRect(viewLocation,
+			      NSInsetRect([view bounds], 2, 2))) {
+		Tk_UpdatePointer((Tk_Window) winPtr, x, y,
+				 [NSApp tkButtonState]);
+	    }
+	} else {
+	    systemDialog = win;
+	}
+	if (winPtr && Tk_IsMapped(winPtr)) {
+	    GenerateActivateEvents(winPtr, true);
+	}
+    }
+    /*
+     * Make sure that the updated keyWindow is associated with the
+     * current TkEventTarget.
+     */
+ 
+    NSWindow *keyWin = [NSApp keyWindow];
+    if (keyWin) {
+	TkWindow *keyWinPtr = TkMacOSXGetTkWindow(keyWin);
+	if (keyWinPtr) {
+	    [NSApp setTkEventTarget:keyWinPtr];
+	}
     }
 }
 
@@ -122,16 +170,21 @@ extern NSString *NSWindowDidOrderOffScreenNotification;
 
 - (void) windowExpanded: (NSNotification *) notification
 {
+    // This method will be called when the asynchronous deminiaturization
+    // operation has completed.  If the window is iconified by clicking on its
+    // dock icon, as opposed to calling wm deiconify, then the Tk state of
+    // the window needs to be updated.  That is the purpose of this method.
+
 #ifdef TK_MAC_DEBUG_NOTIFICATIONS
     TKLog(@"-[%@(%p) %s] %@", [self class], self, sel_getName(_cmd), notification);
 #endif
+
     NSWindow *w = [notification object];
     TkWindow *winPtr = TkMacOSXGetTkWindow(w);
-
-    if (winPtr) {
+    if (winPtr && winPtr->wmInfoPtr->hints.initial_state == IconicState) {
 	winPtr->wmInfoPtr->hints.initial_state =
 		TkMacOSXIsWindowZoomed(winPtr) ? ZoomState : NormalState;
-	Tk_MapWindow((Tk_Window)winPtr);
+	TkWmMapWindow(winPtr);
 
 	/*
 	 * NSWindowDidDeminiaturizeNotification is received after
@@ -194,15 +247,26 @@ extern NSString *NSWindowDidOrderOffScreenNotification;
 
 - (void) windowCollapsed: (NSNotification *) notification
 {
+    // This method will be called when the asynchronous miniaturization
+    // operation has completed.  If the window is iconified by clicking on its
+    // yellow button, as opposed to calling wm iconify, then the Tk state of
+    // the window needs to be updated.  That is the purpose of this method.
+
 #ifdef TK_MAC_DEBUG_NOTIFICATIONS
     TKLog(@"-[%@(%p) %s] %@", [self class], self, sel_getName(_cmd), notification);
 #endif
     NSWindow *w = [notification object];
     TkWindow *winPtr = TkMacOSXGetTkWindow(w);
-
-    if (winPtr) {
-	winPtr->wmInfoPtr->hints.initial_state = IconicState;
-	Tk_UnmapWindow((Tk_Window)winPtr);
+    NSString *name = [notification name];
+    if (!winPtr) {
+	return;
+    }
+    if ([name isEqualToString:NSWindowWillMiniaturizeNotification]) {
+	if (winPtr && winPtr->wmInfoPtr->hints.initial_state != IconicState) {
+	    winPtr->wmInfoPtr->hints.initial_state = IconicState;
+	}
+    } else {
+	TkWmUnmapWindow(winPtr);
     }
 }
 
@@ -238,7 +302,6 @@ extern NSString *NSWindowDidOrderOffScreenNotification;
 	    [view viewDidChangeEffectiveAppearance];
 	}
 #endif
-	[view setNeedsDisplay:YES];
     }
 }
 
@@ -294,10 +357,12 @@ extern NSString *NSWindowDidOrderOffScreenNotification;
 
     observe(NSWindowDidBecomeKeyNotification, windowActivation:);
     observe(NSWindowDidResignKeyNotification, windowActivation:);
+    observe(NSWindowWillCloseNotification, windowActivation:);
     observe(NSWindowDidMoveNotification, windowBoundsChanged:);
     observe(NSWindowDidResizeNotification, windowBoundsChanged:);
     observe(NSWindowDidDeminiaturizeNotification, windowExpanded:);
     observe(NSWindowDidMiniaturizeNotification, windowCollapsed:);
+    observe(NSWindowWillMiniaturizeNotification, windowCollapsed:);
     observe(NSWindowWillOrderOnScreenNotification, windowMapped:);
     observe(NSWindowDidOrderOnScreenNotification, windowBecameVisible:);
     observe(NSWindowWillStartLiveResizeNotification, windowLiveResize:);
@@ -330,10 +395,12 @@ static void RefocusGrabWindow(void *data) {
 
 - (void) applicationActivate: (NSNotification *) notification
 {
-    (void)notification;
+    NSWindow *iconifiedWindow = nil;
 
 #ifdef TK_MAC_DEBUG_NOTIFICATIONS
     TKLog(@"-[%@(%p) %s] %@", [self class], self, sel_getName(_cmd), notification);
+#else
+    (void) notification;
 #endif
     [NSApp tkCheckPasteboard];
 
@@ -357,10 +424,17 @@ static void RefocusGrabWindow(void *data) {
 	}
 	if (winPtr->dispPtr->grabWinPtr == winPtr) {
 	    Tcl_DoWhenIdle(RefocusGrabWindow, winPtr);
-	} else {
-	    [[self keyWindow] orderFront: self];
+	}
+	if (iconifiedWindow == nil && [win isMiniaturized]) {
+	    iconifiedWindow = win;
 	}
     }
+    if ([self keyWindow] == nil && iconifiedWindow != nil) {
+	[iconifiedWindow makeKeyAndOrderFront:self];
+    } else {
+	[[self keyWindow] orderFront:self];
+    }
+
 }
 
 - (void) applicationDeactivate: (NSNotification *) notification
@@ -960,6 +1034,7 @@ ExposeRestrictProc(
 }
 - (void) updateLayer {
     CGContextRef context = self.tkLayerBitmapContext;
+    static bool initialized = NO;
     if (context && ![NSApp tkWillExit]) {
 	/*
 	 * Create a CGImage by copying (probably using copy-on-write) the
@@ -979,7 +1054,10 @@ ExposeRestrictProc(
 	 * Without this there are black flashes when a window opens.
 	 */
 
-	while(Tcl_DoOneEvent(TCL_IDLE_EVENTS)){}
+	if (!initialized) {
+	    while(Tcl_DoOneEvent(TCL_IDLE_EVENTS)){}
+	    initialized = YES;
+	}
     }
 }
 
@@ -1059,12 +1137,6 @@ ExposeRestrictProc(
 	[NSApp _unlockAutoreleasePool];
 
     }
-
-    /*
-     * Request a call to updateLayer.
-     */
-
-    [self setNeedsDisplay:YES];
 }
 
 /*
