@@ -1,8 +1,8 @@
 /*
  * tkUnixXId.c --
  *
- * Copyright (c) 1993 The Regents of the University of California.
- * Copyright (c) 1994-1997 Sun Microsystems, Inc.
+ * Copyright © 1993 The Regents of the University of California.
+ * Copyright © 1994-1997 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -10,39 +10,6 @@
 
 #include "tkUnixInt.h"
 
-
-/*
- *----------------------------------------------------------------------
- *
- * Tk_FreeXId --
- *
- *	This function is called to indicate that an X resource identifier is
- *	now free.
- *
- * Results:
- *	None.
- *
- * Side effects:
- *	The identifier is added to the stack of free identifiers for its
- *	display, so that it can be re-used.
- *
- *----------------------------------------------------------------------
- */
-
-void
-Tk_FreeXId(
-    Display *display,		/* Display for which xid was allocated. */
-    XID xid)			/* Identifier that is no longer in use. */
-{
-    /*
-     * This does nothing, because the XC-MISC extension takes care of
-     * freeing XIDs for us.  It has been a standard X11 extension for
-     * about 15 years as of 2008.  Keith Packard and another X.org
-     * developer suggested that we remove the previous code that used:
-     * #define XLIB_ILLEGAL_ACCESS.
-     */
-}
-
 
 /*
  *----------------------------------------------------------------------
