@@ -3,7 +3,7 @@
  *
  *	This file contains a stub dll entry point.
  *
- * Copyright (c) 1995 Sun Microsystems, Inc.
+ * Copyright © 1995 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -101,9 +101,10 @@ DllMain(
     DWORD reason,
     LPVOID reserved)
 {
-#ifdef HAVE_NO_SEH
+#if defined(HAVE_NO_SEH) && !defined(__aarch64__)
     TCLEXCEPTION_REGISTRATION registration;
 #endif
+    (void)reserved;
 
     /*
      * If we are attaching to the DLL from a new process, tell Tk about the
@@ -123,7 +124,9 @@ DllMain(
 	 */
 
 #ifdef HAVE_NO_SEH
-#   ifdef _WIN64
+#   if defined(__aarch64__)
+	/* Don't run TkFinalize(NULL) on mingw-w64 for ARM64, since we don't have corresponding assembler-code. */
+#   elif defined(_WIN64)
 	__asm__ __volatile__ (
 
 	    /*
